#!/bin/bash

# setup paths and environment to run AGILE and Rivet
set_environment () {
  echo "Setting environment..."
  
  # set SLC5 platform name:
  LCG_PLATFORM=x86_64-slc5-gcc43-opt
  if [[ "$(uname -m)" != "x86_64" ]] ; then
    LCG_PLATFORM=i686-slc5-gcc43-opt
  fi
  
  source /afs/cern.ch/sw/lcg/contrib/gcc/4.3/$LCG_PLATFORM/setup.sh
  
  MCGENERATORS=/afs/cern.ch/sw/lcg/external/MCGenerators
  MCGENERATORS_HEPMC206=/afs/cern.ch/sw/lcg/external/MCGenerators_hepmc20603
  local AGILE=$MCGENERATORS_HEPMC206/agile/1.2.1/$LCG_PLATFORM
  local RIVET=$MCGENERATORS_HEPMC206/rivet/1.5.0a2/$LCG_PLATFORM
  HEPMC=/afs/cern.ch/sw/lcg/external/HepMC/2.06.03/$LCG_PLATFORM
  local PYTHON=/afs/cern.ch/sw/lcg/external/Python/2.6.5/$LCG_PLATFORM
  
  export PYTHONPATH=$AGILE/lib/python2.5/site-packages:$RIVET/lib/python2.5/site-packages:$PYTHONPATH
  export LD_LIBRARY_PATH=$HEPMC/lib:$AGILE/lib:$RIVET/lib:$PYTHON/lib:$LD_LIBRARY_PATH
  export PATH=$PYTHON/bin:$RIVET/bin:$AGILE/bin:$PATH
  export AGILE_GEN_PATH=$MCGENERATORS
  export AGILE_PARAM_PATH=$(pwd)/configuration
  export RIVET_REF_PATH=$(rivet-config --datadir)
  
  echo "LCG_PLATFORM=$LCG_PLATFORM"
  echo "gcc version = $(gcc -dumpversion)"
  echo "AGILE=$AGILE"
  echo "RIVET=$RIVET"
  echo "HEPMC=$HEPMC"
  echo "AGILE_GEN_PATH=$AGILE_GEN_PATH"
  echo "AGILE_PARAM_PATH=$AGILE_PARAM_PATH"
  echo "RIVET_REF_PATH=$RIVET_REF_PATH"
  echo ""
}

rm -rf plots/ pythia6.aida pythia6.hepmc

set_environment

agile-runmc Pythia6:424 --paramfile=pythia6-mb.params --beam=ppbar:200 --nevts=1000 --out=pythia6.hepmc

echo "==============="
rivet -a UA5_1989_S1926373 -H pythia6.aida pythia6.hepmc
rivet-mkhtml -s pythia6.aida


echo "==============="
rivet -a UA1_1990_S2044935 -H pythia6.aida pythia6.hepmc
rivet-mkhtml -s pythia6.aida


